pub struct ZPAQ { /* private fields */ }Expand description
ZPAQ-like chunking algorithm.
Note that this does NOT match the official implementation (the ZPAQ C++
library). This functions the same way, but does not use the same specific
sizes, and does not enforce chunk size limits (unless you use
Chunker::max_size() explicitly). In addition, the constants used by this
implementation are different; see
#6.
Implementations